summaryrefslogtreecommitdiffstats
path: root/src/usr/local/www/services_dhcpv6.php
diff options
context:
space:
mode:
authorPhil Davis <phil.davis@inf.org>2015-11-05 22:01:04 +0545
committerPhil Davis <phil.davis@inf.org>2015-11-05 22:01:04 +0545
commite32f02a56dd79f463102f04ecf39eafcc617e524 (patch)
tree0429f4cccdbb22e0fe21405c63f1acab578c61fe /src/usr/local/www/services_dhcpv6.php
parent846e29bdd74751e34ff0f674258ee54dc40ef0ed (diff)
downloadpfsense-e32f02a56dd79f463102f04ecf39eafcc617e524.zip
pfsense-e32f02a56dd79f463102f04ecf39eafcc617e524.tar.gz
services_dhcpv6 text
and also I made the DNS 1, DNS 2, DNS 3 , DNS 4 show inside the boxes as 'placeholder' the same as NTP 1, NTP 2 is done. That saves a bit of screen real estate and makes it consistent.
Diffstat (limited to 'src/usr/local/www/services_dhcpv6.php')
-rw-r--r--src/usr/local/www/services_dhcpv6.php19
1 files changed, 10 insertions, 9 deletions
diff --git a/src/usr/local/www/services_dhcpv6.php b/src/usr/local/www/services_dhcpv6.php
index ddd64ba..b353ad5 100644
--- a/src/usr/local/www/services_dhcpv6.php
+++ b/src/usr/local/www/services_dhcpv6.php
@@ -457,7 +457,7 @@ if($_GET['act'] == "addopt") {
}
$closehead = false;
-$pgtitle = array(gettext("Services"), gettext("DHCPv6 server"));
+$pgtitle = array(gettext("Services"), gettext("DHCPv6 Server"));
$shortcut_section = "dhcp6";
include("head.inc");
@@ -566,7 +566,7 @@ if(is_ipaddrv6($ifcfgip)) {
if($is_olsr_enabled) {
$section->addInput(new Form_Select(
'netmask',
- 'Subnetmask',
+ 'Subnet Mask',
$pconfig['netmask'],
array_combine(range(128, 1, -1), range(128, 1, -1))
));
@@ -643,8 +643,9 @@ for($i=1;$i<=4; $i++) {
'dns' . $i,
null,
'text',
- $pconfig['dns' . $i]
- ))->setHelp('DNS ' . $i);
+ $pconfig['dns' . $i],
+ ['placeholder' => 'DNS ' . $i]
+ ));
}
$group->setHelp('Leave blank to use the system default DNS servers,this interface\'s IP if DNS forwarder is enabled, or the servers configured on the "General" page.');
@@ -759,7 +760,7 @@ $group->add(new Form_Input(
$group->add(new Form_Input(
'ntp2',
- 'NTP Server 1',
+ 'NTP Server 2',
'text',
$pconfig['ntp2'],
['placeholder' => 'NTP 2']
@@ -797,7 +798,7 @@ $btnnetboot->removeClass('btn-primary')->addClass('btn-default btn-sm');
$section->addInput(new Form_StaticText(
'Network booting',
- $btnnetboot . '&nbsp;' . 'Show Netwok booting'
+ $btnnetboot . '&nbsp;' . 'Show Network booting'
));
$section->addInput(new Form_Checkbox(
@@ -823,7 +824,7 @@ $btnadnl->removeClass('btn-primary')->addClass('btn-default btn-sm');
$section->addInput(new Form_StaticText(
'Additional BOOTP/DHCP Options',
- $btnadnl . '&nbsp;' . 'Aditional BOOTP/DHCP Options'
+ $btnadnl . '&nbsp;' . 'Additional BOOTP/DHCP Options'
));
$form->add($section);
@@ -1008,10 +1009,10 @@ events.push(function(){
hideCheckBox('shownetboot', false);
});
// Make the 'aditional options' button a plain button, not a submit button
$("#btnadnl").prop('type','button');
// Show aditional controls
$("#btnadnl").click(function() {
hideClass('adnlopt', false);
hideInput('btnaddopt', false);
@@ -1008,10 +1009,10 @@ events.push(function(){
hideCheckBox('shownetboot', false);
});
- // Make the 'aditional options' button a plain button, not a submit button
+ // Make the 'additional options' button a plain button, not a submit button
$("#btnadnl").prop('type','button');
@@ -1008,10 +1009,10 @@ events.push(function(){
$("#btnadnl").prop('type','button');
- // Show aditional controls
+ // Show additional controls
$("#btnadnl").click(function() {
hideClass('adnlopt', false);
OpenPOWER on IntegriCloud